@@ -18,7 +18,7 @@
   
 ## Class Global Values ############################ 
   our @ISA = qw(Exporter);
-  our $VERSION = '2.2.5';
+  our $VERSION = '2.2';
   our $errstr = ();
   our @EXPORT_OK = ($VERSION, $errstr);
 
@@ -32,9 +32,10 @@
      unless (
          (exists ($p{Server})) &&
          (exists ($p{User}))   &&
+         (exists ($p{Pass}))   &&
          (exists ($p{DBType})) 
      ){
-         $errstr = "Server, User, and DBType are required options to New";
+         $errstr = "Server, User, Pass, and DBType are required options to New";
          return (undef);
      }
     #if it's Oracle, we'll be needing a SID too
@@ -62,7 +63,7 @@
     #local vars
      my $self = shift();
      my %p = @_;
-     my ($connect_str, @connect_args) = ();
+     my ($connect_str) = ();
     #are we already logged in?
      if (exists ($self->{dbh})){ return (1); }
     #require appropriate dbi module
@@ -82,11 +83,6 @@
          }else{
              $connect_str = "dbi:Oracle:host=$self->{Server};sid=$self->{SID}";
          }
-     }elsif ($self->{DBType} eq "mysql"){
-         $connect_str = "dbi:mysql";
-         if ($self->{'Database'}){ $connect_str .= ":database=$self->{'Database'}"; }
-         $connect_str .= ";host=$self->{Server};";
-         if ($self->{'Port'}){ $connect_str .= "port=$self->{'Port'};"; }
      }else{
         #wow this is really ghetto
          $self->{errstr} = "Sorry Dude, ";
@@ -94,11 +90,12 @@
          $self->{errstr}.= "someone needs to edit YAWM.pm";
          return (undef);
      }
-     push (@connect_args, $connect_str);
-     push (@connect_args, $self->{User});
-     push (@connect_args, $self->{Pass}) if (exists($self->{Pass}));
     #make the connection
-     unless ($self->{dbh} = DBI->connect(@connect_args)){
+     unless ($self->{dbh} = DBI->connect(
+         $connect_str,
+         $self->{User},
+         $self->{Pass}
+     )){
          $self->{errstr} = "Login failed: $DBI::errstr";
          return (undef);
      }
@@ -221,22 +218,18 @@ sub Insert {
              delete($p{Insert}->{$_});
              next;
          }
+        #escape " 's
+         $p{Insert}->{$_} =~s/\"/\"\"/g;
      }
-     
-     #Ints has been replaced by 'NoQuote', but we maintain
-     #backward compatibility
-     foreach (keys %{$p{'Ints'}}){ $p{'NoQuote'}->{$_} = 1; }
-    
     #formulate the sql
      my $field_names = join (', ', sort (keys %{$p{Insert}}));
      foreach (sort (keys %{$p{Insert}})){
-     	if (exists($p{'NoQuote'}->{$_})){
-     		push (@vals, $p{Insert}->{$_});
-     	}else{
-     		push (@vals, $self->{dbh}->quote($p{Insert}->{$_}));
-     	}
+         if (exists ($p{Ints}->{$_})){
+             push (@vals, "$p{Insert}->{$_}");
+         }else{
+             push (@vals, "\"$p{Insert}->{$_}\"");
+         }
      }
-     
      my $field_values = join (', ',@vals);
      my $sql = "INSERT INTO $p{Into} ($field_names) VALUES ($field_values)";
     #prepare the statement
@@ -256,84 +249,3 @@ sub Insert {
     #well it must be all-good
      return (1);
 }
-
-
-## Do #############################################
-## prepare and execute an SQL statement of no
-## particular type. If errors are encountered undef is
-## returned and errors go on $obj->{errstr} as usual
-## if successfull, whatever is returned from dbi->execute
-## is returned here
-sub Do {
-    #local vars
-     my ($self, %p) = @_;
-    #required options
-     unless (exists($p{SQL})){
-         $self->{'errstr'} = "[Do]: SQL is a required option to Do";
-         return (undef);
-     }
-    #prepare statement
-     warn ("[Do]: (prepare): $p{SQL}") if $self->{'Debug'};
-     my $sth = $self->{dbh}->prepare($p{SQL}) || do {
-         $self->{'errstr'} = "[Do]: failed to prepare SQL ($p{SQL}): $DBI::errstr";
-         warn ($self->{'errstr'}) if $self->{'Debug'};
-         return (undef);
-     };
-     warn ("[Do]: (executing)") if $self->{'Debug'};
-     my $res = $sth->execute() || do {
-         $self->{'errstr'} = "[Do]: failed to execute SQL ($p{SQL}): $DBI::errstr";
-         warn ($self->{'errstr'}) if $self->{'Debug'};
-         return (undef);
-     };
-     $sth->finish();
-     return ($res);
-}
-
-
-## Update #########################################
-## update a record (or records) in the database with 
-## new field settings
-sub Update {
-	my ($self, %p) = @_;
-   #required options
-   	exists($p{'Table'}) || do {
-   		$self->{'errstr'} = "[Update]: 'Table' specifies the table of view to update the record(s) in, please specify";
-		warn ($self->{'errstr'}) if $self->{'Debug'};
-		return (undef);
-   	};
-   	exists($p{'Where'}) || do {
-   		$self->{'errstr'} = "[Update]: 'Where' specified which record(s) in 'Table' to update. please specify";
-   		warn ($self->{'errstr'}) if $self->{'Debug'};
-		return (undef);
-   	};
-   	exists($p{'Fields'}) || do {
-   		$self->{'errstr'} = "[Update]: 'Fields' is a hash reference indicating the field values to update, please specify";
-   		warn ($self->{'errstr'}) if $self->{'Debug'};
-		return (undef);
-   	};
-   #construct SQL String
-    my $sql = "update $p{'Table'} set ";
-    my @fields = ();
-	foreach (keys %{$p{'Fields'}}){
-		my $str = "$_ = ";
-		$str   .= $self->{dbh}->quote($p{'Fields'}->{$_});
-		push (@fields, $str); 
-	}
-	$sql .= join(", ", @fields);
-	$sql .= " ";
-	$sql .= "where $p{'Where'}";
-    warn("[Update]: (prepare): $sql\n") if $self->{'Debug'};
-   #prepare sql
-    my $sth = $self->{dbh}->prepare($sql) || do {
-    	$self->{'errstr'} = "[Update]: failed to prepare sql statement $DBI::errstr [SQL]: $sql";
-    	warn ($self->{'errstr'}) if $self->{'Debug'};
-        return (undef);
-    };
-   #execute sql
-    $sth->execute() || do {
-    	$self->{'errstr'} = "[Update]: failed to execute sql: $DBI::errstr";
-    	warn ($self->{'errstr'}) if $self->{'Debug'};
-        return (undef);
-    };
-    return (1);
-}
